@@ -23,8 +23,8 @@ from lean.components.config.project_config_manager import ProjectConfigManager
 from lean.components.config.storage import Storage
 from lean.components.util.logger import Logger
 from lean.constants import DEFAULT_LEAN_CONFIG_FILE_NAME, GUI_PRODUCT_INSTALL_ID
-from lean.models.config import DebuggingMethod
 from lean.models.errors import MoreInfoError
+from lean.models.utils import DebuggingMethod
 
 
 class LeanConfigManager:
@@ -80,7 +80,7 @@ class LeanConfigManager:
             # If the parent directory is the same as the current directory we can't go up any more
             if current_dir.parent == current_dir:
                 raise MoreInfoError(f"'{DEFAULT_LEAN_CONFIG_FILE_NAME}' not found",
-                                    "https://www.lean.io/docs/lean-cli/user-guides/configuration#03-Lean-configuration")
+                                    "https://www.lean.io/docs/lean-cli/initialization/configuration#03-Lean-Configuration")
 
             current_dir = current_dir.parent
 
