@@ -12,6 +12,7 @@
 # limitations under the License.
 
 import hashlib
+import os
 from datetime import datetime, timedelta, timezone
 from distutils.version import StrictVersion
 
@@ -51,10 +52,12 @@ class UpdateManager:
         self._cache_storage = cache_storage
         self._docker_manager = docker_manager
 
-    def warn_if_cli_outdated(self) -> None:
+    def warn_if_cli_outdated(self, force: bool = False) -> None:
         """Warns the user if the CLI is outdated.
 
-        An update check is performed once every UPDATE_CHECK_INTERVAL_CLI hours.
+        An update check is performed once every UPDATE_CHECK_INTERVAL_CLI hours, unless force is set to True.
+
+        :param force: whether the update check interval should be bypassed (defaults to False)
         """
         current_version = lean.__version__
 
@@ -62,7 +65,7 @@ class UpdateManager:
         if current_version == "dev":
             return
 
-        if not self._should_check_for_updates("cli", UPDATE_CHECK_INTERVAL_CLI):
+        if not force and not self._should_check_for_updates("cli", UPDATE_CHECK_INTERVAL_CLI):
             return
 
         try:
@@ -80,29 +83,40 @@ class UpdateManager:
             self._logger.warn(f"A new release of the Lean CLI is available ({current_version} -> {latest_version})")
             self._logger.warn("Run `pip install --upgrade lean` to update to the latest version")
 
-    def warn_if_docker_image_outdated(self, image: DockerImage) -> None:
-        """Warns the user if the latest installed version of a Docker image is outdated.
+    def pull_docker_image_if_necessary(self, image: DockerImage, force: bool) -> None:
+        """Pulls a Docker image if necessary.
 
-        An update check is performed once every UPDATE_CHECK_INTERVAL_DOCKER_IMAGE hours (the interval is per image).
+        Docker images are pulled when they are not installed yet,
+        and once every UPDATE_CHECK_INTERVAL_DOCKER_IMAGE hours (the interval is per image).
+
+        :param image: the image to pull
+        :param force: skip the interval check to force a pull
         """
-        # Don't consider checking for updates if the latest version of the image isn't installed yet
-        if not self._docker_manager.image_installed(image):
-            return
+        if not force and self._docker_manager.image_installed(image):
+            if not self._should_check_for_updates(str(image), UPDATE_CHECK_INTERVAL_DOCKER_IMAGE):
+                return
 
-        if not self._should_check_for_updates(str(image), UPDATE_CHECK_INTERVAL_DOCKER_IMAGE):
-            return
+            local_digest = self._docker_manager.get_local_digest(image)
 
-        local_digest = self._docker_manager.get_local_digest(image)
+            # If the local digest does not exist the image was built locally so there is nothing to pull
+            if local_digest is None:
+                return
 
-        try:
-            remote_digest = self._docker_manager.get_remote_digest(image)
-        except APIError:
-            # The user may be offline, do nothing
-            return
+            try:
+                remote_digest = self._docker_manager.get_remote_digest(image)
+            except APIError:
+                # The user may be offline, do nothing
+                return
 
-        if local_digest != remote_digest:
-            self._logger.warn(f"You are currently using an outdated version of the '{image}' Docker image")
-            self._logger.warn(f"Run this command with the --update flag to update it to the latest version")
+            # Do nothing if we're already using the latest image
+            if remote_digest == local_digest:
+                return
+
+            # Don't update existing image when running from local GUI
+            if os.environ.get("QC_LOCAL_GUI", "false") == "true":
+                return
+
+        self._docker_manager.pull_image(image)
 
     def show_announcements(self) -> None:
         """Shows the announcements if they have been updated.
